==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/outputs/NamedAgentPoolProfileResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Agent pool profile along with a name parameter
 * @property availabilityZones AvailabilityZones - The list of Availability zones to use for nodes. Datacenter racks modelled as zones
 * @property cloudProviderProfile The underlying cloud infra provider properties.
 * @property count Count - Number of agents to host docker containers. Allowed values must be in the range of 1 to 100 (inclusive). The default value is 1.
 * @property maxCount The maximum number of nodes for auto-scaling
 * @property maxPods The maximum number of pods that can run on a node.
 * @property minCount The minimum number of nodes for auto-scaling
 * @property mode Mode - AgentPoolMode represents mode of an agent pool. Possible values include: 'System', 'LB', 'User'. Default is 'User'
 * @property name Unique name of the agent pool profile in the context of the subscription and resource group.
 * @property nodeImageVersion The version of node image
 * @property nodeLabels NodeLabels - Agent pool node labels to be persisted across all nodes in agent pool.
 * @property nodeTaints NodeTaints - Taints added to new nodes during node pool create and scale. For example, key=value:NoSchedule.
 * @property osType OsType - OsType to be used to specify os type. Choose from Linux and Windows. Default to Linux. Possible values include: 'Linux', 'Windows'
 * @property vmSize VmSize - The size of the agent pool VMs.
 */
public data class NamedAgentPoolProfileResponse(
    public val availabilityZones: List<String>? = null,
    public val cloudProviderProfile: CloudProviderProfileResponse? = null,
    public val count: Int? = null,
    public val maxCount: Int? = null,
    public val maxPods: Int? = null,
    public val minCount: Int? = null,
    public val mode: String? = null,
    public val name: String? = null,
    public val nodeImageVersion: String? = null,
    public val nodeLabels: Map<String, String>? = null,
    public val nodeTaints: List<String>? = null,
    public val osType: String? = null,
    public val vmSize: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.hybridcontainerservice.outputs.NamedAgentPoolProfileResponse):
            NamedAgentPoolProfileResponse = NamedAgentPoolProfileResponse(
            availabilityZones = javaType.availabilityZones().map({ args0 -> args0 }),
            cloudProviderProfile = javaType.cloudProviderProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs.CloudProviderProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            count = javaType.count().map({ args0 -> args0 }).orElse(null),
            maxCount = javaType.maxCount().map({ args0 -> args0 }).orElse(null),
            maxPods = javaType.maxPods().map({ args0 -> args0 }).orElse(null),
            minCount = javaType.minCount().map({ args0 -> args0 }).orElse(null),
            mode = javaType.mode().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            nodeImageVersion = javaType.nodeImageVersion().map({ args0 -> args0 }).orElse(null),
            nodeLabels = javaType.nodeLabels().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            nodeTaints = javaType.nodeTaints().map({ args0 -> args0 }),
            osType = javaType.osType().map({ args0 -> args0 }).orElse(null),
            vmSize = javaType.vmSize().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/outputs/NamedAgentPoolProfileResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Agent pool profile along with a name parameter
 * @property availabilityZones AvailabilityZones - The list of Availability zones to use for nodes. Datacenter racks modelled as zones
 * @property cloudProviderProfile The underlying cloud infra provider properties.
 * @property count Count - Number of agents to host docker containers. Allowed values must be in the range of 1 to 100 (inclusive). The default value is 1.
 * @property maxCount The maximum number of nodes for auto-scaling
 * @property maxPods The maximum number of pods that can run on a node.
 * @property minCount The minimum number of nodes for auto-scaling
 * @property mode Mode - AgentPoolMode represents mode of an agent pool. Possible values include: 'System', 'LB', 'User'. Default is 'User'
 * @property name Unique name of the agent pool profile in the context of the subscription and resource group.
 * @property nodeImageVersion The version of node image
 * @property nodeLabels NodeLabels - Agent pool node labels to be persisted across all nodes in agent pool.
 * @property nodeTaints NodeTaints - Taints added to new nodes during node pool create and scale. For example, key=value:NoSchedule.
 * @property osType OsType - OsType to be used to specify os type. Choose from Linux and Windows. Default to Linux. Possible values include: 'Linux', 'Windows'
 * @property vmSize VmSize - The size of the agent pool VMs.
 */
public data class NamedAgentPoolProfileResponse(
    public val availabilityZones: List<String>? = null,
    public val cloudProviderProfile: CloudProviderProfileResponse? = null,
    public val count: Int? = null,
    public val maxCount: Int? = null,
    public val maxPods: Int? = null,
    public val minCount: Int? = null,
    public val mode: String? = null,
    public val name: String? = null,
    public val nodeImageVersion: String? = null,
    public val nodeLabels: Map<String, String>? = null,
    public val nodeTaints: List<String>? = null,
    public val osType: String? = null,
    public val vmSize: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.hybridcontainerservice.outputs.NamedAgentPoolProfileResponse): NamedAgentPoolProfileResponse = NamedAgentPoolProfileResponse(
            availabilityZones = javaType.availabilityZones().map({ args0 -> args0 }),
            cloudProviderProfile = javaType.cloudProviderProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs.CloudProviderProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            count = javaType.count().map({ args0 -> args0 }).orElse(null),
            maxCount = javaType.maxCount().map({ args0 -> args0 }).orElse(null),
            maxPods = javaType.maxPods().map({ args0 -> args0 }).orElse(null),
            minCount = javaType.minCount().map({ args0 -> args0 }).orElse(null),
            mode = javaType.mode().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            nodeImageVersion = javaType.nodeImageVersion().map({ args0 -> args0 }).orElse(null),
            nodeLabels = javaType.nodeLabels().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            nodeTaints = javaType.nodeTaints().map({ args0 -> args0 }),
            osType = javaType.osType().map({ args0 -> args0 }).orElse(null),
            vmSize = javaType.vmSize().map({ args0 -> args0 }).orElse(null),
        )
    }
}
